@@ -1,7 +1,9 @@
 from .base import AutoPackagerRunner
+from .javascript import JavaScriptRunner
 from .python_poetry import PythonPoetryRunner
 
 __all__ = (
     "AutoPackagerRunner",
+    "JavaScriptRunner",
     "PythonPoetryRunner",
 )
